config

package module
v0.0.0-...-0fc559f Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jan 24, 2026 License: MPL-2.0 Imports: 5 Imported by: 0

README

config

Package config parses config files in toml format wrapping an existing toml parser with some utility functions.

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func LoadFromApplicationPath

func LoadFromApplicationPath(v any) (toml.MetaData, error)

LoadFromApplicationPath gets the executable directory and then calls LoadFromDir with the path of that directory.

func LoadFromDir

func LoadFromDir(path string, v any) (toml.MetaData, error)

LoadFromDir lists the files at path and if exactly one .toml file is found it calls LoadFromFile with the path to that file.

func LoadFromFile

func LoadFromFile(path string, v any) (toml.MetaData, error)

LoadFromFile decodes the .toml file at path and loads its values into v, returning the meta and a possible error from the toml parser.

Types

This section is empty.

Jump to