Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func LoadFromApplicationPath ¶
LoadFromApplicationPath gets the executable directory and then calls LoadFromDir with the path of that directory.
func LoadFromDir ¶
LoadFromDir lists the files at path and if exactly one .toml file is found it calls LoadFromFile with the path to that file.
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.